package com.rwk.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.rwk.system.mapper.RwkFamilyMemberMapper;
import com.rwk.system.domain.RwkFamilyMember;
import com.rwk.system.service.IRwkFamilyMemberService;
import com.rwk.common.core.text.Convert;

/**
 * 家庭成员Service业务层处理
 * 
 * @author rick
 * @date 2024-11-06
 */
@Service
public class RwkFamilyMemberServiceImpl implements IRwkFamilyMemberService 
{
    @Autowired
    private RwkFamilyMemberMapper rwkFamilyMemberMapper;

    /**
     * 查询家庭成员
     * 
     * @param id 家庭成员主键
     * @return 家庭成员
     */
    @Override
    public RwkFamilyMember selectRwkFamilyMemberById(Long id)
    {
        return rwkFamilyMemberMapper.selectRwkFamilyMemberById(id);
    }

    /**
     * 查询家庭成员列表
     * 
     * @param rwkFamilyMember 家庭成员
     * @return 家庭成员
     */
    @Override
    public List<RwkFamilyMember> selectRwkFamilyMemberList(RwkFamilyMember rwkFamilyMember)
    {
        return rwkFamilyMemberMapper.selectRwkFamilyMemberList(rwkFamilyMember);
    }

    /**
     * 新增家庭成员
     * 
     * @param rwkFamilyMember 家庭成员
     * @return 结果
     */
    @Override
    public int insertRwkFamilyMember(RwkFamilyMember rwkFamilyMember)
    {
        return rwkFamilyMemberMapper.insertRwkFamilyMember(rwkFamilyMember);
    }

    /**
     * 修改家庭成员
     * 
     * @param rwkFamilyMember 家庭成员
     * @return 结果
     */
    @Override
    public int updateRwkFamilyMember(RwkFamilyMember rwkFamilyMember)
    {
        return rwkFamilyMemberMapper.updateRwkFamilyMember(rwkFamilyMember);
    }

    /**
     * 批量删除家庭成员
     * 
     * @param ids 需要删除的家庭成员主键
     * @return 结果
     */
    @Override
    public int deleteRwkFamilyMemberByIds(String ids)
    {
        return rwkFamilyMemberMapper.deleteRwkFamilyMemberByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除家庭成员信息
     * 
     * @param id 家庭成员主键
     * @return 结果
     */
    @Override
    public int deleteRwkFamilyMemberById(Long id)
    {
        return rwkFamilyMemberMapper.deleteRwkFamilyMemberById(id);
    }
}
